## $Id: utils.py 13614 2016-01-14 10:43:10Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Customize general helper utilities for Kofa.
"""
from copy import deepcopy
from kofacustom.nigeria.utils.utils import NigeriaKofaUtils
from waeup.fceokene.interfaces import MessageFactory as _

class CustomKofaUtils(NigeriaKofaUtils):
    """A collection of methods subject to customization.
    """

    PREFERRED_LANGUAGES_DICT = {
        }

    APP_CATS_DICT = {
        'basic': 'UTME, DE, PCE, PRENCE',
        'no': 'No Application',
        'sandwich': 'Sandwich',
        'cest': 'Part-Time, Diploma, Certificate',
        'bec': 'Bachelor of Education Certificate Programmes',
        }

    SPECIAL_HANDLING_DICT = {
        'regular': 'Regular Hostel',
        'blocked': 'Blocked Hostel',
        'ugft': 'Undergraduate Fulltime Hostel'
        }

    PAYMENT_CATEGORIES = {
        'schoolfee': 'School Fee',
        'clearance': 'Acceptance Fee',
        'bed_allocation': 'Bed Allocation Fee',
        'hostel_maintenance': 'Hostel Maintenance Fee',
        #'transfer': 'Transfer Fee',
        #'gown': 'Gown Hire Fee',
        'application': 'Application Fee',
        #'transcript': 'Transcript Fee',
        'third_semester': 'NCE Third Semester Fee',
        }

    DISABLE_PAYMENT_GROUP_DICT = {
        'sf_all': 'School Fee - All Students',
        'sf_nce1': 'School Fee - NCE I Fresh Students',
        }

    SELECTABLE_PAYMENT_CATEGORIES = deepcopy(PAYMENT_CATEGORIES)

    VERDICTS_DICT = {
        '0': 'not yet',
        'A': 'Successful student',
        'B': 'Student with carryover courses',
        'C': 'Student on probation',
        'D': 'Withdrawn from the faculty',
        #'E': 'Student who were previously on probation',
        #'F': 'Medical case',
        'G': 'Absent from examination',
        #'H': 'Withheld results',
        'I': 'Expelled/rusticated/suspended student',
        'J': 'Temporary withdrawn from the university',
        #'K': 'Unregistered student',
        'L': 'Referred student',
        'M': 'Reinstatement',
        #'N': 'Student on transfer',
        'O': 'NCE-III repeater',
        #'Y': 'No previous verdict',
        #'X': 'New 300 level student (Uniben)',
        'Z': 'Successful student (provisional)',
        'A1': 'First Class',
        'A2': 'Second Class Upper',
        'A3': 'Second Class Lower',
        'A4': 'Third Class',
        'A5': 'Pass',
        'A6': 'Distinction',
        'A7': 'Credit',
        'A8': 'Merit',
        'OPDE': 'PDE repeater',
        }

    def getPaymentItem(self, payment):
        """Return payment item.

        Bed coordinates are only visible after payment.
        """
        if 'maintenance' in payment.p_category and payment.p_state != 'paid':
            return _('(visible after successful payment)')
        return payment.p_item